pub struct CoreMetrics {Show 17 fields
pub lsm_get_total: AtomicU64,
pub lsm_put_total: AtomicU64,
pub lsm_delete_total: AtomicU64,
pub lsm_compaction_total: AtomicU64,
pub lsm_wal_writes_total: AtomicU64,
pub cache_hits_total: AtomicU64,
pub cache_misses_total: AtomicU64,
pub cache_evictions_total: AtomicU64,
pub buffer_allocations_total: AtomicU64,
pub buffer_recycles_total: AtomicU64,
pub buffer_pool_misses_total: AtomicU64,
pub fhe_encrypt_us_total: AtomicU64,
pub fhe_decrypt_us_total: AtomicU64,
pub fhe_operation_count: AtomicU64,
pub memtable_size_bytes: AtomicU64,
pub sstable_count: AtomicU64,
pub compaction_level: AtomicU64,
/* private fields */
}Expand description
Metrics facade for the amaters-core storage engine.
All fields are updated via atomic operations for lock-free access from
multiple threads. Call to_prometheus() to get an OpenMetrics/Prometheus
text snapshot.
Fields
lsm_get_total: AtomicU64lsm_put_total: AtomicU64lsm_delete_total: AtomicU64lsm_compaction_total: AtomicU64lsm_wal_writes_total: AtomicU64cache_hits_total: AtomicU64cache_misses_total: AtomicU64cache_evictions_total: AtomicU64buffer_allocations_total: AtomicU64buffer_recycles_total: AtomicU64buffer_pool_misses_total: AtomicU64fhe_encrypt_us_total: AtomicU64fhe_decrypt_us_total: AtomicU64fhe_operation_count: AtomicU64memtable_size_bytes: AtomicU64sstable_count: AtomicU64compaction_level: AtomicU64Implementations
Sourceimpl CoreMetrics
impl CoreMetrics
Sourcepub fn record_get_latency_us(&self, us: u64)
pub fn record_get_latency_us(&self, us: u64)
Record a GET operation latency in microseconds.
Sourcepub fn record_put_latency_us(&self, us: u64)
pub fn record_put_latency_us(&self, us: u64)
Record a PUT operation latency in microseconds.
Sourcepub fn cache_hit_rate(&self) -> f64
pub fn cache_hit_rate(&self) -> f64
Compute the block cache hit rate as a value in [0.0, 1.0].
Returns 0.0 when no cache events have been recorded.
Sourcepub fn to_prometheus(&self) -> String
pub fn to_prometheus(&self) -> String
Render all metrics as an OpenMetrics/Prometheus text exposition.