pub struct CompactionPlanner { /* private fields */ }Expand description
Compaction planner
Implementations
Sourceimpl CompactionPlanner
impl CompactionPlanner
Sourcepub fn new(config: CompactionConfig) -> Self
pub fn new(config: CompactionConfig) -> Self
Create a new compaction planner
Sourcepub fn needs_l0_compaction(&self, l0_sstable_count: usize) -> bool
pub fn needs_l0_compaction(&self, l0_sstable_count: usize) -> bool
Check if L0 needs compaction
Sourcepub fn needs_level_compaction(&self, level: usize, level_size: u64) -> bool
pub fn needs_level_compaction(&self, level: usize, level_size: u64) -> bool
Check if a level needs compaction
Sourcepub fn level_target_size(&self, level: usize) -> u64
pub fn level_target_size(&self, level: usize) -> u64
Calculate target size for a level
Sourcepub fn plan_compaction(
&self,
source_level: usize,
source_sstables: Vec<SSTableMetadata>,
target_sstables: Vec<SSTableMetadata>,
) -> Option<CompactionTask>
pub fn plan_compaction( &self, source_level: usize, source_sstables: Vec<SSTableMetadata>, target_sstables: Vec<SSTableMetadata>, ) -> Option<CompactionTask>
Plan a compaction task (level-based strategy)
Sourcepub fn plan_size_tiered_compaction(
&self,
sstables: Vec<SSTableMetadata>,
) -> Option<CompactionTask>
pub fn plan_size_tiered_compaction( &self, sstables: Vec<SSTableMetadata>, ) -> Option<CompactionTask>
Plan a size-tiered compaction task
Groups SSTables by similar size (within size_ratio of each other).
When a tier has at least min_tier_size SSTables, they are merged.
Sourcepub fn group_by_size_tier(
&self,
sstables: Vec<SSTableMetadata>,
) -> Vec<SizeTier>
pub fn group_by_size_tier( &self, sstables: Vec<SSTableMetadata>, ) -> Vec<SizeTier>
Group SSTables into size tiers
SSTables are grouped such that the largest file in a tier is at most
size_ratio times the smallest file in the same tier.
Sourcepub fn find_overlapping_sstables(
&self,
source_sstables: &[SSTableMetadata],
target_sstables: &[SSTableMetadata],
) -> Vec<SSTableMetadata>
pub fn find_overlapping_sstables( &self, source_sstables: &[SSTableMetadata], target_sstables: &[SSTableMetadata], ) -> Vec<SSTableMetadata>
Find overlapping SSTables in target level